@@ -32,7 +32,6 @@ from oslo_rootwrap import subprocess
 
 from tripleo_common.actions import base
 from tripleo_common import constants
-from tripleo_common import inventory
 
 LOG = logging.getLogger(__name__)
 
@@ -46,49 +45,33 @@ def write_default_ansible_cfg(work_dir,
     ansible_config_path = os.path.join(work_dir, 'ansible.cfg')
     shutil.copy(base_ansible_cfg, ansible_config_path)
 
-    modules_path = (
-        '/root/.ansible/plugins/modules:'
-        '/usr/share/ansible/tripleo-plugins/modules:'
-        '/usr/share/ansible/plugins/modules:'
-        '/usr/share/ansible-modules:'
-        '{}/library:'
-        '{}/library'.format(constants.DEFAULT_VALIDATIONS_BASEDIR,
-                            constants.DEFAULT_VALIDATIONS_LEGACY_BASEDIR))
+    modules_path = ('/root/.ansible/plugins/modules:'
+                    '/usr/share/ansible/tripleo-plugins/modules:'
+                    '/usr/share/ansible/plugins/modules:'
+                    '/usr/share/ansible-modules:'
+                    '%s/library' % constants.DEFAULT_VALIDATIONS_BASEDIR)
     lookups_path = (
         '/root/.ansible/plugins/lookup:'
         '/usr/share/ansible/tripleo-plugins/lookup:'
         '/usr/share/ansible/plugins/lookup:'
-        '{}/lookup_plugins:'
-        '{}/lookup_plugins'.format(
-            constants.DEFAULT_VALIDATIONS_BASEDIR,
-            constants.DEFAULT_VALIDATIONS_LEGACY_BASEDIR))
+        '%s/lookup_plugins' % constants.DEFAULT_VALIDATIONS_BASEDIR)
     callbacks_path = (
         '~/.ansible/plugins/callback:'
         '/usr/share/ansible/tripleo-plugins/callback:'
         '/usr/share/ansible/plugins/callback:'
-        '{}/callback_plugins:'
-        '{}/callback_plugins'.format(
-            constants.DEFAULT_VALIDATIONS_BASEDIR,
-            constants.DEFAULT_VALIDATIONS_LEGACY_BASEDIR))
-
+        '%s/callback_plugins' % constants.DEFAULT_VALIDATIONS_BASEDIR)
     callbacks_whitelist = ','.join(['tripleo_dense', 'tripleo_profile_tasks',
                                     'tripleo_states'])
     action_plugins_path = (
         '~/.ansible/plugins/action:'
         '/usr/share/ansible/plugins/action:'
         '/usr/share/ansible/tripleo-plugins/action:'
-        '{}/action_plugins:'
-        '{}/action_plugins'.format(
-            constants.DEFAULT_VALIDATIONS_BASEDIR,
-            constants.DEFAULT_VALIDATIONS_LEGACY_BASEDIR))
+        '%s/action_plugins' % constants.DEFAULT_VALIDATIONS_BASEDIR)
     filter_plugins_path = (
         '~/.ansible/plugins/filter:'
         '/usr/share/ansible/plugins/filter:'
         '/usr/share/ansible/tripleo-plugins/filter:'
-        '{}/filter_plugins:'
-        '{}/filter_plugins'.format(
-            constants.DEFAULT_VALIDATIONS_BASEDIR,
-            constants.DEFAULT_VALIDATIONS_LEGACY_BASEDIR))
+        '%s/filter_plugins' % constants.DEFAULT_VALIDATIONS_BASEDIR)
     roles_path = ('%(work_dir)s/roles:'
                   '/root/.ansible/roles:'
                   '/usr/share/ansible/tripleo-roles:'
@@ -97,8 +80,7 @@ def write_default_ansible_cfg(work_dir,
                   '%(ooo_val_path)s/roles:'
                   '%(work_dir)s' % {
                       'work_dir': work_dir,
-                      'ooo_val_path':
-                          constants.DEFAULT_VALIDATIONS_LEGACY_BASEDIR
+                      'ooo_val_path': constants.DEFAULT_VALIDATIONS_BASEDIR
                   })
 
     config = configparser.ConfigParser()
@@ -121,13 +103,7 @@ def write_default_ansible_cfg(work_dir,
                     datetime.now().strftime("%Y-%m-%dT%H:%M:%S"))
         os.rename(log_path, new_path)
 
-    # Create the log file, and set some rights on it in order to prevent
-    # unwanted access
-    open(log_path, 'a').close()
-    os.chmod(log_path, 0o640)
-
-    config.set('defaults', 'forks', str(min(
-        multiprocessing.cpu_count() * 4, 100)))
+    config.set('defaults', 'forks', str(multiprocessing.cpu_count() * 10))
     config.set('defaults', 'timeout', '30')
     config.set('defaults', 'gather_timeout', '30')
 
@@ -136,11 +112,6 @@ def write_default_ansible_cfg(work_dir,
     config.set('defaults', 'fact_caching', 'jsonfile')
     config.set('defaults', 'fact_caching_connection',
                '~/.ansible/fact_cache')
-    # NOTE(mwhahaha): only gather the bare minimum facts because this has
-    # direct impact on how fast ansible can go.
-    config.set('defaults', 'gather_subset', '!all,min')
-    # NOTE(mwhahaha): this significantly affects performation per ansible#73654
-    config.set('defaults', 'inject_facts_as_vars', 'false')
 
     # Set the pull interval to lower CPU overhead
     config.set('defaults', 'internal_poll_interval', '0.05')
@@ -180,7 +151,7 @@ def write_default_ansible_cfg(work_dir,
         sio_cfg = StringIO()
         sio_cfg.write(override_ansible_cfg)
         sio_cfg.seek(0)
-        config.read_file(sio_cfg)
+        config.readfp(sio_cfg)
         sio_cfg.close()
 
     with open(ansible_config_path, 'w') as configfile:
@@ -368,8 +339,8 @@ class AnsiblePlaybookAction(base.TripleOAction):
         python_version = sys.version_info.major
         ansible_playbook_cmd = "ansible-playbook-{}".format(python_version)
 
-        if 1 < self.verbosity < 6:
-            verbosity_option = '-' + ('v' * (self.verbosity - 1))
+        if 0 < self.verbosity < 6:
+            verbosity_option = '-' + ('v' * self.verbosity)
             command = [ansible_playbook_cmd, verbosity_option,
                        self.playbook]
         else:
@@ -541,33 +512,3 @@ class AnsiblePlaybookAction(base.TripleOAction):
                 msg = "An error happened while cleaning work directory: " + e
                 LOG.error(msg)
                 return actions.Result(error=msg)
-
-
-class AnsibleGenerateInventoryAction(base.TripleOAction):
-    """Executes tripleo-ansible-inventory to generate an inventory"""
-
-    def __init__(self, **kwargs):
-        self._kwargs_for_run = kwargs
-        self.ansible_ssh_user = self._kwargs_for_run.pop(
-            'ansible_ssh_user', 'tripleo-admin')
-        self.undercloud_key_file = self._kwargs_for_run.pop(
-            'undercloud_key_file', None)
-        self.ansible_python_interpreter = self._kwargs_for_run.pop(
-            'ansible_python_interpreter', None)
-        self.work_dir = self._kwargs_for_run.pop(
-            'work_dir', None)
-        self.plan_name = self._kwargs_for_run.pop(
-            'plan_name', 'overcloud')
-        self.ssh_network = self._kwargs_for_run.pop(
-            'ssh_network', 'ctlplane')
-
-    def run(self, context):
-        return inventory.generate_tripleo_ansible_inventory(
-            heat=self.get_orchestration_client(context),
-            work_dir=self.work_dir,
-            plan=self.plan_name,
-            auth=context.security,
-            ansible_ssh_user=self.ansible_ssh_user,
-            undercloud_key_file=self.undercloud_key_file,
-            ansible_python_interpreter=self.ansible_python_interpreter,
-            ssh_network=self.ssh_network)
