@@ -17,7 +17,7 @@
 
 from collections import OrderedDict
 import logging
-import os
+import os.path
 import sys
 import tempfile
 import yaml
@@ -148,8 +148,6 @@ class TripleoInventory(object):
             return alist
 
     def _get_stack(self):
-        if self.plan_name is None:
-            return None
         try:
             stack = self.hclient.stacks.get(self.plan_name)
         except HTTPNotFound:
@@ -169,15 +167,8 @@ class TripleoInventory(object):
                     'ansible_connection': self.undercloud_connection,
                     # see https://github.com/ansible/ansible/issues/41808
                     'ansible_remote_tmp': '/tmp/ansible-${USER}',
-                    # We don't want to let UC fail, especially when it comes to
-                    # external tasks. Thus setting any_error_fatal and
-                    # max_fail_percentage
-                    # See https://bugs.launchpad.net/tripleo/+bug/1960518 for
-                    # context
-                    'any_error_fatal': True,
                     'auth_url': self.auth_url,
-                    'max_fail_percentage': 0,
-                    'plan': None,
+                    'plan': self.plan_name,
                     'project_name': self.project_name,
                     'username': self.username,
                 },
@@ -202,6 +193,12 @@ class TripleoInventory(object):
         ret['Undercloud']['vars']['undercloud_service_list'] = \
             self.get_undercloud_service_list()
 
+        admin_password = self.get_overcloud_environment().get(
+            'parameter_defaults', {}).get('AdminPassword')
+        if admin_password:
+            ret['Undercloud']['vars']['overcloud_admin_password'] =\
+                admin_password
+
         if dynamic:
             # Prevent Ansible from repeatedly calling us to get empty host
             # details
@@ -210,14 +207,6 @@ class TripleoInventory(object):
         self.stack = self._get_stack()
         if not self.stack:
             return ret
-
-        ret['Undercloud']['vars']['plan'] = self.plan_name
-        admin_password = self.get_overcloud_environment().get(
-            'parameter_defaults', {}).get('AdminPassword')
-        if admin_password:
-            ret['Undercloud']['vars']['overcloud_admin_password'] =\
-                admin_password
-
         self.stack_outputs = StackOutputs(self.stack)
 
         keystone_url = self.stack_outputs.get('KeystoneURL')
@@ -389,17 +378,13 @@ class TripleoInventory(object):
                 if var in inventory:
                     inventory[var]['vars'].update(value)
 
-        # Atomic update as concurrent tripleoclient commands can call this
-        inventory_file_dir = os.path.dirname(inventory_file_path)
-        with tempfile.NamedTemporaryFile(
-                'w',
-                dir=inventory_file_dir,
-                delete=False) as inventory_file:
+        with open(inventory_file_path, 'w') as inventory_file:
             yaml.dump(inventory, inventory_file, TemplateDumper)
-        os.rename(inventory_file.name, inventory_file_path)
 
 
-def generate_tripleo_ansible_inventory(heat, auth,
+def generate_tripleo_ansible_inventory(heat, auth_url,
+                                       username,
+                                       project_name,
                                        cacert=None,
                                        plan='overcloud',
                                        work_dir=None,
@@ -414,10 +399,10 @@ def generate_tripleo_ansible_inventory(heat, auth,
         work_dir, 'tripleo-ansible-inventory.yaml')
     inv = TripleoInventory(
         hclient=heat,
-        auth_url=auth.auth_uri,
+        auth_url=auth_url,
+        username=username,
+        project_name=project_name,
         cacert=cacert,
-        project_name=auth.project_name,
-        username=auth.user_name,
         ansible_ssh_user=ansible_ssh_user,
         undercloud_key_file=undercloud_key_file,
         ansible_python_interpreter=ansible_python_interpreter,
