@@ -741,7 +741,7 @@ class PlanTest(base.TestCase):
         }
         mock_resource = mock.MagicMock()
         mock_resource.attributes = {
-            'endpoint_map': None,
+            'endpoint_map': {},
             'value': None
         }
         mock_orchestration.resources.get.return_value = mock_resource
@@ -907,7 +907,6 @@ class PlanTest(base.TestCase):
 
         existing_passwords = _EXISTING_PASSWORDS.copy()
         existing_passwords.pop("AdminPassword")
-        existing_passwords.pop("PcsdPassword")
 
         swift = mock.MagicMock(url="http://test.com")
         mock_env = yaml.safe_dump({
@@ -924,7 +923,6 @@ class PlanTest(base.TestCase):
         mock_orchestration.stacks.environment.return_value = {
             'parameter_defaults': {
                 'AdminPassword': 'ExistingPasswordInHeat',
-                'PcsdPassword': 'MyPassword'
             }
         }
 
@@ -940,7 +938,6 @@ class PlanTest(base.TestCase):
         result = plan_utils.generate_passwords(swift, mock_orchestration)
 
         existing_passwords["AdminPassword"] = "ExistingPasswordInHeat"
-        existing_passwords["PcsdPassword"] = "MyPassword"
         # ensure old passwords used and no new generation
         self.assertEqual(existing_passwords, result)
         mock_cache.assert_called_once_with(
@@ -1034,7 +1031,7 @@ class PlanTest(base.TestCase):
 
         kib.assert_called_once_with(
             [os.path.join(sys.prefix, 'share', 'tripleo-common',
-                          'container-images', 'tripleo_containers.yaml.j2')]
+                          'container-images', 'overcloud_containers.yaml.j2')]
         )
         params = {
             'ContainerNovaComputeImage': 't/cb-nova-compute:liberty',
