@@ -17,6 +17,7 @@
 import json
 import logging
 import os
+import re
 import requests
 import sys
 import tempfile
@@ -32,7 +33,8 @@ from tripleo_common import constants
 from tripleo_common.image import kolla_builder
 from tripleo_common.utils import passwords as password_utils
 from tripleo_common.utils import swift as swiftutils
-from tripleo_common.utils.validations import pattern_validator
+
+LOG = logging.getLogger(__name__)
 
 LOG = logging.getLogger(__name__)
 
@@ -300,7 +302,7 @@ def default_image_params():
 
     template_file = os.path.join(sys.prefix, 'share', 'tripleo-common',
                                  'container-images',
-                                 'tripleo_containers.yaml.j2')
+                                 'overcloud_containers.yaml.j2')
     builder = kolla_builder.KollaImageBuilder([template_file])
     result = builder.container_images_from_template(filter=ffunc)
 
@@ -406,10 +408,9 @@ def generate_passwords(swift, heat, mistral=None,
         # We don't modify these to avoid changing defaults
         for pw_res in constants.LEGACY_HEAT_PASSWORD_RESOURCE_NAMES:
             try:
+                res = heat.resources.get(container, pw_res)
                 param_defaults = stack_env.get('parameter_defaults', {})
-                if pw_res not in param_defaults:
-                    res = heat.resources.get(container, pw_res)
-                    param_defaults[pw_res] = res.attributes['value']
+                param_defaults[pw_res] = res.attributes['value']
             except heat_exc.HTTPNotFound:
                 LOG.debug('Heat resouce not found: %s' % pw_res)
                 pass
@@ -417,17 +418,16 @@ def generate_passwords(swift, heat, mistral=None,
     except heat_exc.HTTPNotFound:
         stack_env = None
 
-    placement_extracted = False
     try:
         # We can't rely on the existence of PlacementPassword to
         # determine if placement extraction has occured as it was added
         # in stein while the service extraction was delayed to train.
         # Inspect the endpoint map instead.
         endpoint_res = heat.resources.get(container, 'EndpointMap')
-        endpoints = endpoint_res.attributes.get('endpoint_map', None)
-        placement_extracted = endpoints and 'PlacementPublic' in endpoints
+        endpoints = endpoint_res.attributes.get('endpoint_map', {})
+        placement_extracted = 'PlacementPublic' in endpoints
     except heat_exc.HTTPNotFound:
-        pass
+        placement_extracted = False
 
     passwords = password_utils.generate_passwords(
         stack_env=stack_env,
@@ -562,3 +562,10 @@ def purge_excess_keys(max_keys, keys_map):
     for key_path in key_paths[1:keys_to_be_purged + 1]:
         del keys_map[key_path]
     return keys_map
+
+
+def pattern_validator(pattern, value):
+    LOG.debug('Validating %s with pattern %s', value, pattern)
+    if not re.match(pattern, value):
+        return False
+    return True
